@@ -42,12 +42,12 @@ class BookListAPIView:
 
     @api_view.doc(summary="get book list")
     async def get(self, query: BookQuery):
-        return query.json()
+        return query.model_dump_json()
 
     @api_view.doc(summary="create book")
     async def post(self, body: BookBody):
-        """description for create book"""
-        return body.json()
+        """description for a created book"""
+        return body.model_dump_json()
 
 
 app.register_api_view(api_view)
