@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# @Author  : [martinatseequent](https://github.com/martinatseequent)
+# @Author  : llc
 # @Time    : 2021/6/22 9:32
 
 import json
@@ -11,7 +11,7 @@ from pydantic import BaseModel, Field
 from flask_openapi3 import Info
 from flask_openapi3 import OpenAPI, APIBlueprint
 
-app = OpenAPI(__name__, info=Info(title="Hello API", version="1.0.0"), )
+app = OpenAPI(__name__, info=Info(title="Hello API", version="1.0.0"))
 
 bp = APIBlueprint("Hello BP", __name__)
 
@@ -23,8 +23,29 @@ class HelloPath(BaseModel):
 class Message(BaseModel):
     message: str = Field(..., description="The message")
 
+    model_config = dict(
+        openapi_extra={
+            # "example": {"message": "aaa"},
+            "examples": {
+                "example1": {
+                    "summary": "example1 summary",
+                    "value": {
+                        "message": "bbb"
+                    }
+                },
+                "example2": {
+                    "summary": "example2 summary",
+                    "value": {
+                        "message": "ccc"
+                    }
+                }
+            }
+        }
+    )
 
-@bp.get("/hello/<string:name>", responses={"200": Message})
+
+@bp.get("/hello/<string:name>",
+        responses={HTTPStatus.OK: Message, "201": {"content": {"text/csv": {"schema": {"type": "string"}}}}})
 def hello(path: HelloPath):
     message = {"message": f"""Hello {path.name}!"""}
 
@@ -34,7 +55,7 @@ def hello(path: HelloPath):
     return response
 
 
-@bp.get("/hello_no_response/<string:name>", responses={"204": None})
+@bp.get("/hello_no_response/<string:name>", responses={204: None})
 def hello_no_response(path: HelloPath):
     message = {"message": f"""Hello {path.name}!"""}
 
