@@ -6,14 +6,14 @@ from pydantic import BaseModel
 from flask_openapi3 import Info, Tag
 from flask_openapi3 import OpenAPI, Server
 
-info = Info(title='book API', version='1.0.0')
+info = Info(title="book API", version="1.0.0")
 servers = [
-    Server(url='http://127.0.0.1:5000'),
-    Server(url='https://127.0.0.1:5000'),
+    Server(url="http://127.0.0.1:5000"),
+    Server(url="https://127.0.0.1:5000"),
 ]
 app = OpenAPI(__name__, info=info, servers=servers)
 
-book_tag = Tag(name='book', description='Some Book')
+book_tag = Tag(name="book", description="Some Book")
 
 
 class BookQuery(BaseModel):
@@ -21,10 +21,10 @@ class BookQuery(BaseModel):
     author: str
 
 
-@app.get('/book', tags=[book_tag])
+@app.get("/book", tags=[book_tag])
 def get_book(query: BookQuery):
     """get books
-    get all books
+    to get all books
     """
     return {
         "code": 0,
