@@ -1,13 +1,9 @@
 # -*- coding: utf-8 -*-
 # @Author  : llc
 # @Time    : 2021/5/11 14:03
-
-from typing import List
-
 from pydantic import BaseModel, Field
 
-from flask_openapi3 import OpenAPI, FileStorage, ExtraRequestBody
-from flask_openapi3 import Encoding
+from flask_openapi3 import OpenAPI, FileStorage
 
 app = OpenAPI(__name__)
 
@@ -18,17 +14,9 @@ class UploadFileForm(BaseModel):
 
 
 class UploadFilesForm(BaseModel):
-    files: List[FileStorage]
-    str_list: List[str]
-    int_list: List[int]
-
-
-extra_form = ExtraRequestBody(
-    description="This is form RequestBody",
-    required=True,
-    # replace style (default to form)
-    encoding={"str_list": Encoding(style="simple")}
-)
+    files: list[FileStorage]
+    str_list: list[str]
+    int_list: list[int]
 
 
 @app.post('/upload/file')
@@ -39,7 +27,7 @@ def upload_file(form: UploadFileForm):
     return {"code": 0, "message": "ok"}
 
 
-@app.post('/upload/files', extra_form=extra_form)
+@app.post('/upload/files')
 def upload_files(form: UploadFilesForm):
     print(form.files)
     print(form.str_list)
