@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # @Author  : llc
 # @Time    : 2023/7/4 9:41
-from typing import Dict, Optional
+from typing import Optional
 
 from pydantic import BaseModel
 
@@ -12,7 +12,7 @@ class Discriminator(BaseModel):
     """
 
     propertyName: str
-    mapping: Optional[Dict[str, str]] = None
+    mapping: Optional[dict[str, str]] = None
 
     model_config = {
         "extra": "allow"
