@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # @Author  : llc
 # @Time    : 2023/7/4 9:41
-from typing import TYPE_CHECKING, Dict, Optional, Union
+from typing import TYPE_CHECKING, Optional, Union
 
 from pydantic import BaseModel
 
@@ -19,7 +19,7 @@ class Encoding(BaseModel):
     """
 
     contentType: Optional[str] = None
-    headers: Optional[Dict[str, Union[Header, Reference]]] = None
+    headers: Optional[dict[str, Union[Header, Reference]]] = None
     style: Optional[str] = None
     explode: Optional[bool] = None
     allowReserved: bool = False
