@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # @Author  : llc
 # @Time    : 2023/7/4 9:47
-from typing import Dict, Optional
+from typing import Optional
 
 from pydantic import BaseModel
 
@@ -14,7 +14,7 @@ class OAuthFlow(BaseModel):
     authorizationUrl: Optional[str] = None
     tokenUrl: Optional[str] = None
     refreshUrl: Optional[str] = None
-    scopes: Dict[str, str]
+    scopes: dict[str, str]
 
     model_config = {
         "extra": "allow"
