@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # @Author  : llc
 # @Time    : 2023/7/4 9:57
-from typing import List, Optional
+from typing import Optional
 
 from pydantic import BaseModel, Field
 
@@ -11,7 +11,7 @@ class ServerVariable(BaseModel):
     https://spec.openapis.org/oas/v3.1.0#server-variable-object
     """
 
-    enum: Optional[List[str]] = Field(None, min_length=1)
+    enum: Optional[list[str]] = Field(None, min_length=1)
     default: str
     description: Optional[str] = None
 
