@@ -5,7 +5,7 @@ import os
 import re
 import sys
 from importlib import import_module
-from typing import Optional, List, Dict, Union, Any, Type, Callable
+from typing import Optional, Union, Any, Type, Callable
 
 from flask import Flask, Blueprint, render_template_string
 from pydantic import BaseModel
@@ -53,10 +53,10 @@ class OpenAPI(APIScaffold, Flask):
             info: Optional[Info] = None,
             security_schemes: Optional[SecuritySchemesDict] = None,
             responses: Optional[ResponseDict] = None,
-            servers: Optional[List[Server]] = None,
+            servers: Optional[list[Server]] = None,
             external_docs: Optional[ExternalDocumentation] = None,
             operation_id_callback: Callable = get_operation_id_for_path,
-            openapi_extensions: Optional[Dict[str, Any]] = None,
+            openapi_extensions: Optional[dict[str, Any]] = None,
             validation_error_status: Union[str, int] = 422,
             validation_error_model: Type[BaseModel] = ValidationErrorModel,
             validation_error_callback: Callable = make_validation_error_response,
@@ -110,13 +110,13 @@ class OpenAPI(APIScaffold, Flask):
         self.responses = convert_responses_key_to_string(responses or {})
 
         # Initialize instance variables
-        self.paths: Dict = dict()
-        self.components_schemas: Dict = dict()
+        self.paths: dict = dict()
+        self.components_schemas: dict = dict()
         self.components = Components()
 
         # Initialize lists for tags and tag names
-        self.tags: List[Tag] = []
-        self.tag_names: List[str] = []
+        self.tags: list[Tag] = []
+        self.tag_names: list[str] = []
 
         # Set URL prefixes and endpoints
         self.doc_prefix = doc_prefix
@@ -145,7 +145,12 @@ class OpenAPI(APIScaffold, Flask):
         self.cli.add_command(openapi_command)  # type: ignore
 
         # Initialize specification JSON
-        self.spec_json: Dict = {}
+        self.spec_json: dict = {}
+        self.spec = APISpec(
+            openapi=self.openapi_version,
+            info=self.info,
+            paths=self.paths
+        )
 
     def _init_doc(self) -> None:
         """
@@ -204,7 +209,7 @@ class OpenAPI(APIScaffold, Flask):
         self.register_blueprint(blueprint)
 
     @property
-    def api_doc(self) -> Dict:
+    def api_doc(self) -> dict:
         """
         Generate the OpenAPI specification JSON.
 
@@ -215,21 +220,24 @@ class OpenAPI(APIScaffold, Flask):
         if self.spec_json:
             return self.spec_json
 
-        spec = APISpec(
-            openapi=self.openapi_version,
-            info=self.info,
-            paths=self.paths
-        )
+        self.generate_spec_json()
+
+        return self.spec_json
+
+    def generate_spec_json(self):
+        self.spec.openapi = self.openapi_version
+        self.spec.info = self.info
+        self.spec.paths = self.paths
 
         if self.severs:
-            spec.servers = self.severs
+            self.spec.servers = self.severs
 
         if self.external_docs:
-            spec.externalDocs = self.external_docs
+            self.spec.externalDocs = self.external_docs
 
         # Set tags
         if self.tags:
-            spec.tags = self.tags
+            self.spec.tags = self.tags
 
         # Add ValidationErrorModel to components schemas
         schema = get_model_schema(self.validation_error_model)
@@ -243,10 +251,10 @@ class OpenAPI(APIScaffold, Flask):
         # Set components
         self.components.schemas = self.components_schemas
         self.components.securitySchemes = self.security_schemes
-        spec.components = self.components
+        self.spec.components = self.components
 
         # Convert spec to JSON
-        self.spec_json = spec.model_dump(mode="json", by_alias=True, exclude_unset=True, warnings=False)
+        self.spec_json = self.spec.model_dump(mode="json", by_alias=True, exclude_unset=True, warnings=False)
 
         # Update with OpenAPI extensions
         self.spec_json.update(**self.openapi_extensions)
@@ -272,15 +280,19 @@ class OpenAPI(APIScaffold, Flask):
                     }
                 }
 
-        return self.spec_json
-
-    def register_api(self, api: APIBlueprint) -> None:
+    def register_api(self, api: APIBlueprint, **options: Any) -> None:
         """
         Register an APIBlueprint.
 
         Args:
             api: The APIBlueprint instance to register.
 
+            options: Additional keyword arguments are passed to :class:`~flask.blueprints.BlueprintSetupState`.
+            They can be accessed in :meth:`~flask.Blueprint.record` callbacks.
+            url_prefix, Blueprint routes will be prefixed with this.
+            subdomain, Blueprint routes will match on this subdomain.
+            url_defaults, Blueprint routes will use these default values for view arguments.
+
         """
         for tag in api.tags:
             if tag.name not in self.tag_names:
@@ -291,20 +303,31 @@ class OpenAPI(APIScaffold, Flask):
                 self.tag_names.append(tag.name)
 
         # Update paths with the APIBlueprint's paths
+        url_prefix = options.get("url_prefix")
+        if url_prefix and api.url_prefix and url_prefix != api.url_prefix:
+            api.paths = {url_prefix + k.removeprefix(api.url_prefix): v for k, v in api.paths.items()}
+        elif url_prefix and not api.url_prefix:
+            api.paths = {url_prefix.rstrip("/") + "/" + k.lstrip("/"): v for k, v in api.paths.items()}
         self.paths.update(**api.paths)
 
         # Update component schemas with the APIBlueprint's component schemas
         self.components_schemas.update(**api.components_schemas)
 
         # Register the APIBlueprint with the current instance
-        self.register_blueprint(api)
+        self.register_blueprint(api, **options)
 
-    def register_api_view(self, api_view: APIView, view_kwargs: Optional[Dict[Any, Any]] = None) -> None:
+    def register_api_view(
+            self,
+            api_view: APIView,
+            url_prefix: Optional[str] = None,
+            view_kwargs: Optional[dict[Any, Any]] = None
+    ) -> None:
         """
         Register APIView
 
         Args:
             api_view: The APIView instance to register.
+            url_prefix: A path to prepend to all the APIView's urls
             view_kwargs: Additional keyword arguments to pass to the API views.
         """
         if view_kwargs is None:
@@ -320,13 +343,17 @@ class OpenAPI(APIScaffold, Flask):
                 self.tag_names.append(tag.name)
 
         # Update paths with the APIView's paths
+        if url_prefix and api_view.url_prefix and url_prefix != api_view.url_prefix:
+            api_view.paths = {url_prefix + k.removeprefix(api_view.url_prefix): v for k, v in api_view.paths.items()}
+        elif url_prefix and not api_view.url_prefix:
+            api_view.paths = {url_prefix.rstrip("/") + "/" + k.lstrip("/"): v for k, v in api_view.paths.items()}
         self.paths.update(**api_view.paths)
 
         # Update component schemas with the APIView's component schemas
         self.components_schemas.update(**api_view.components_schemas)
 
         # Register the APIView with the current instance
-        api_view.register(self, view_kwargs=view_kwargs)
+        api_view.register(self, url_prefix=url_prefix, view_kwargs=view_kwargs)
 
     def _add_url_rule(
             self,
@@ -343,16 +370,16 @@ class OpenAPI(APIScaffold, Flask):
             rule: str,
             func: Callable,
             *,
-            tags: Optional[List[Tag]] = None,
+            tags: Optional[list[Tag]] = None,
             summary: Optional[str] = None,
             description: Optional[str] = None,
             external_docs: Optional[ExternalDocumentation] = None,
             operation_id: Optional[str] = None,
             responses: Optional[ResponseDict] = None,
             deprecated: Optional[bool] = None,
-            security: Optional[List[Dict[str, List[Any]]]] = None,
-            servers: Optional[List[Server]] = None,
-            openapi_extensions: Optional[Dict[str, Any]] = None,
+            security: Optional[list[dict[str, list[Any]]]] = None,
+            servers: Optional[list[Server]] = None,
+            openapi_extensions: Optional[dict[str, Any]] = None,
             doc_ui: bool = True,
             method: str = HTTPMethod.GET
     ) -> ParametersTuple:
